enum AlternateMediaType { all, movies, shows, seasons, episodes, lists }

enum TraktMediaItemType { all, movie, show, season, episode, list, person }

enum CommentType { all, reviews, shouts }

enum TimePeriod { weekly, monthly, yearly, all }

enum ListSortBy {
  rank,
  added,
  title,
  released,
  runtime,
  popularity,
  percentage,
  votes,
  my_rating,
  random,
  watched,
  collected
}

enum ListSortHow { asc, desc }

enum ListCommentsSortBy { newest, oldest, likes, replies }

enum MovieCommentsSortBy {
  newest,
  oldest,
  likes,
  replies,
  highest,
  lowest,
  plays
}

enum MediaListTypes { all, personal, official, watchlists, recommendations }

enum MediaListSortBy { popular, likes, comments, items, added, updated }

enum PeopleListTypes { all, personal, official }

enum PeopleListSortBy { popular, likes, comments, items, added, updated }

enum SearchMediaItemType { movie, show, episode, list, person }

enum SearchMediaIdType { trakt, imdb, tmdb, tvdb }

enum ShowCommentsSortBy {
  newest,
  oldest,
  likes,
  replies,
  highest,
  lowest,
  plays,
  watched
}
enum UserLikesType { comments, lists }

enum ShowLastActivity { aired, collected }

enum UserSection {
  calendar,
  progress_watched,
  progress_watched_reset,
  progress_collected,
  recommendations
}

/// Extensions

extension UserLikesTypeExtension on UserLikesType {
  String toJson() {
    switch (this) {
      case UserLikesType.comments:
        return 'comments';
      case UserLikesType.lists:
        return 'lists';
      default:
        return 'lists';
    }
  }
}

extension UserSectionExtension on UserSection {
  String toJson() {
    switch (this) {
      case UserSection.calendar:
        return 'calendar';
      case UserSection.progress_watched:
        return 'progress_watched';
      case UserSection.progress_watched_reset:
        return 'progress_watched_reset';
      case UserSection.progress_collected:
        return 'progress_collected';
      case UserSection.recommendations:
        return 'recommendations';
      default:
        return 'recommendations';
    }
  }
}

extension ShowLastActivityExtension on ShowLastActivity {
  String toJson() {
    switch (this) {
      case ShowLastActivity.aired:
        return 'aired';
      case ShowLastActivity.collected:
        return 'collected';
      default:
        return 'aired';
    }
  }
}

extension ShowCommentsSortByExtension on ShowCommentsSortBy {
  String toJson() {
    switch (this) {
      case ShowCommentsSortBy.newest:
        return 'newest';
      case ShowCommentsSortBy.oldest:
        return 'oldest';
      case ShowCommentsSortBy.likes:
        return 'likes';
      case ShowCommentsSortBy.replies:
        return 'replies';
      case ShowCommentsSortBy.highest:
        return 'highest';
      case ShowCommentsSortBy.lowest:
        return 'lowest';
      case ShowCommentsSortBy.plays:
        return 'plays';
      case ShowCommentsSortBy.watched:
        return 'watched';
      default:
        return 'newest';
    }
  }
}

extension SearchMediaIdTypeExtension on SearchMediaIdType {
  String toJson() {
    switch (this) {
      case SearchMediaIdType.trakt:
        return 'trakt';
      case SearchMediaIdType.imdb:
        return 'imdb';
      case SearchMediaIdType.tmdb:
        return 'tmdb';
      case SearchMediaIdType.tvdb:
        return 'tvdb';
      default:
        return 'trakt';
    }
  }
}

extension MediaListSortByExtension on MediaListSortBy {
  String toJson() {
    switch (this) {
      case MediaListSortBy.popular:
        return 'popular';
      case MediaListSortBy.likes:
        return 'likes';
      case MediaListSortBy.comments:
        return 'comments';
      case MediaListSortBy.items:
        return 'items';
      case MediaListSortBy.added:
        return 'added';
      case MediaListSortBy.updated:
        return 'updated';
      default:
        return 'popular';
    }
  }
}

extension PeopleListTypesExtension on PeopleListTypes {
  String toJson() {
    switch (this) {
      case PeopleListTypes.personal:
        return 'personal';
      case PeopleListTypes.official:
        return 'official';
      case PeopleListTypes.all:
        return 'all';
      default:
        return 'all';
    }
  }
}

extension MediaListTypesExtension on MediaListTypes {
  String toJson() {
    switch (this) {
      case MediaListTypes.personal:
        return 'personal';
      case MediaListTypes.official:
        return 'official';
      case MediaListTypes.watchlists:
        return 'watchlists';
      case MediaListTypes.recommendations:
        return 'recommendations';
      case MediaListTypes.all:
        return 'all';
      default:
        return 'all';
    }
  }
}

extension TimePeriodExtension on TimePeriod {
  String toJson() {
    switch (this) {
      case TimePeriod.weekly:
        return 'weekly';
      case TimePeriod.monthly:
        return 'monthly';
      case TimePeriod.yearly:
        return 'yearly';
      case TimePeriod.all:
        return 'all';
      default:
        return 'monthly';
    }
  }
}

extension AlternateMediaTypeExtension on AlternateMediaType {
  String toJson() {
    switch (this) {
      case AlternateMediaType.movies:
        return 'all';
      case AlternateMediaType.movies:
        return 'movies';
      case AlternateMediaType.shows:
        return 'shows';
      case AlternateMediaType.seasons:
        return 'seasons';
      case AlternateMediaType.episodes:
        return 'episodes';
      case AlternateMediaType.lists:
        return 'lists';
      default:
        return 'movies';
    }
  }
}

extension ListCommentsSortByExtension on ListCommentsSortBy {
  String toJson() {
    switch (this) {
      case ListCommentsSortBy.newest:
        return 'newest';
      case ListCommentsSortBy.oldest:
        return 'oldest';
      case ListCommentsSortBy.likes:
        return 'likes';
      case ListCommentsSortBy.replies:
        return 'replies';

      default:
        return 'newest';
    }
  }
}

extension MovieCommentsSortByExtension on MovieCommentsSortBy {
  String toJson() {
    switch (this) {
      case MovieCommentsSortBy.newest:
        return 'newest';
      case MovieCommentsSortBy.oldest:
        return 'oldest';
      case MovieCommentsSortBy.likes:
        return 'likes';
      case MovieCommentsSortBy.replies:
        return 'replies';
      case MovieCommentsSortBy.highest:
        return 'highest';
      case MovieCommentsSortBy.lowest:
        return 'lowest';
      case MovieCommentsSortBy.plays:
        return 'plays';
      default:
        return 'newest';
    }
  }
}

extension ListSortHowExtension on ListSortHow {
  String toJson() {
    switch (this) {
      case ListSortHow.asc:
        return 'asc';
      case ListSortHow.desc:
        return 'asc';
      default:
        return 'desc';
    }
  }
}

extension ListSortByExtension on ListSortBy {
  String toJson() {
    switch (this) {
      case ListSortBy.rank:
        return 'rank';
      case ListSortBy.added:
        return 'added';
      case ListSortBy.title:
        return 'title';
      case ListSortBy.released:
        return 'released';
      case ListSortBy.runtime:
        return 'runtime';
      case ListSortBy.popularity:
        return 'popularity';
      case ListSortBy.percentage:
        return 'percentage';
      case ListSortBy.votes:
        return 'votes';
      case ListSortBy.my_rating:
        return 'my_rating';
      case ListSortBy.random:
        return 'random';
      case ListSortBy.watched:
        return 'watched';
      case ListSortBy.collected:
        return 'collected';
      default:
        return 'rank';
    }
  }
}

extension CommentTypeExtension on CommentType {
  String toJson() {
    switch (this) {
      case CommentType.all:
        return 'all';
      case CommentType.reviews:
        return 'reviews';
      case CommentType.shouts:
        return 'shouts';
      default:
        return 'all';
    }
  }
}

extension TraktMediaItemTypeExtension on TraktMediaItemType {
  String toJson() {
    switch (this) {
      case TraktMediaItemType.all:
        return 'all';
      case TraktMediaItemType.movie:
        return 'movie';
      case TraktMediaItemType.show:
        return 'show';
      case TraktMediaItemType.season:
        return 'show';
      case TraktMediaItemType.episode:
        return 'show';
      case TraktMediaItemType.list:
        return 'list';
      case TraktMediaItemType.person:
        return 'person';
      default:
        return 'movie';
    }
  }
}

extension SearchMediaItemTypeExtension on SearchMediaItemType {
  String toJson() {
    switch (this) {
      case SearchMediaItemType.movie:
        return 'movie';
      case SearchMediaItemType.show:
        return 'show';
      case SearchMediaItemType.episode:
        return 'show';
      case SearchMediaItemType.list:
        return 'list';
      case SearchMediaItemType.person:
        return 'person';
      default:
        return 'movie';
    }
  }
}
