import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'auth.g.dart';

@RestApi()
abstract class Auth {
  factory Auth(Dio dio, {String baseUrl}) = _Auth;

  @GET("/oauth/authorize")
  Future<HttpResponse<dynamic>> authorizeApplication(
    @Query('response_type') String responseType,
    @Query('redirect_uri') String redirectUri, {
    @Query('client_id') String clientId,
    @Query('state') String state,
    @Queries() Map<String, dynamic> additionalQueries,
    @Header("content-type") String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
  });

  @POST("/oauth/token")
  Future<HttpResponse<dynamic>> getAccessTokenFromOAuth(
    @Body() GetAccessTokenFromOauthBody getAccessTokenFromOauthBody, {
    @Header("content-type") String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST("/oauth/token")
  Future<HttpResponse<dynamic>> refreshAccessToken(
    @Body() RefreshAccessTokenBody refreshAccessTokenBody, {
    @Header("content-type") String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST("/oauth/revoke")
  Future<HttpResponse<dynamic>> revokeAccessToken(
    @Body() RevokeAccessTokenBody revokeAccessTokenBody, {
    @Header("content-type") String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST("/oauth/device/code")
  Future<HttpResponse<dynamic>> getDeviceCode(
    @Body() GetDeviceCodeBody getDeviceCodeBody, {
    @Header("content-type") String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST("/oauth/device/code")
  Future<HttpResponse<dynamic>> getAccessTokenFromDeviceCode(
    @Body() GetAccessTokenFromDeviceCodeBody getAccessTokenFromDeviceCodeBody, {
    @Header("content-type") String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
