import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';

part 'calendars.g.dart';

@RestApi()
abstract class Calendars {
  factory Calendars(Dio dio, {String baseUrl}) = _Calendars;

  @GET('/calendars/my/shows/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getMyShows({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,

    /// extended levels of information by adding ?extended={level} to the URL.
    /// Send a comma separated string to get multiple types of extended info.
    /// Level	Description
    /// full - Complete info for an item.
    /// episodes - Add episode information to the season.
    /// metadata - Collection only. Additional video and audio info.
    @Query('extended') String extendedInfo,

    /// Search titles and descriptions. example : 'Mulan'
    @Query('query') String query,

    /// 4 digit year or range of years. example : '2006'
    @Query('years') String years,

    /// Genre slugs. Multiple values. example : 'action'
    @Query('genres') String genres,

    /// 2 character language code. Multiple values. example : 'en'
    @Query('languages') String languages,

    /// 2 character country code. Multiple values. example : 'us'
    @Query('countries') String countries,

    /// Range in minutes. example : '30-90'
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,

    /// 	Range between 0 and 100. example : '75-100'
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/my/shows/new/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getMyNewShows({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/my/shows/premieres/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getMySeasonPremieres({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/my/movies/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getMyMovies({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/my/dvd/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getMyDVD({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/all/shows/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getAllShows({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/all/shows/new/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getAllNewShows({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/all/shows/premieres/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getAllSeasonPremieres({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/all/movies/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getAllMovies({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/calendars/all/dvd/{start_date}/{days}')
  Future<HttpResponse<dynamic>> getAllDVD({
    @Path('start_date') String startDate,
    @Path('days') int days,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
