import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'comments.g.dart';

@RestApi()
abstract class Comments {
  factory Comments(Dio dio, {String baseUrl}) = _Comments;

  @POST('/comments')
  Future<HttpResponse<dynamic>> addComment(
    @Body() CommentBody commentBody, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/comments/{id}')
  Future<HttpResponse<dynamic>> getComments(
    @Path('id') int commentId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @PUT('/comments/{id}')
  Future<HttpResponse<dynamic>> updateComment(
    @Path('id') int commentId,
    @Body() CommentBody commentBody, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @DELETE('/comments/{id}')
  Future<HttpResponse<dynamic>> deleteComment(
    @Path('id') int commentId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/comments/{id}/replies')
  Future<HttpResponse<dynamic>> getReplies(
    @Path('id') int commentId, {
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/comments/{id}/replies')
  Future<HttpResponse<dynamic>> postReply(
    @Path('id') int commentId,
    @Body() ReplyBody replyBody, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/comments/{id}/item')
  Future<HttpResponse<dynamic>> getMediaItem(
    @Path('id') int commentId, {
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/comments/{id}/likes')
  Future<HttpResponse<dynamic>> getAllLiked(
    @Path('id') int commentId, {
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/comments/{id}/like')
  Future<HttpResponse<dynamic>> like(
    @Path('id') int commentId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @DELETE('/comments/{id}/like')
  Future<HttpResponse<dynamic>> unlike(
    @Path('id') int commentId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/comments/trending/{comment_type}/{type}')
  Future<HttpResponse<dynamic>> getTrending({
    @Path('comment_type') CommentType commentType,
    @Path('type') TraktMediaItemType traktMediaItemType,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('include_replies') bool includeReplies,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/comments/recent/{comment_type}/{type}')
  Future<HttpResponse<dynamic>> getRecent({
    @Path('comment_type') CommentType commentType,
    @Path('type') TraktMediaItemType traktMediaItemType,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('include_replies') bool includeReplies,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/comments/updates/{comment_type}/{type}')
  Future<HttpResponse<dynamic>> getRecentUpdated({
    @Path('comment_type') CommentType commentType,
    @Path('type') TraktMediaItemType traktMediaItemType,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('include_replies') bool includeReplies,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
