import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';

import '../../../trakt.dart';

part 'episodes.g.dart';

@RestApi()
abstract class Episodes {
  factory Episodes(Dio dio, {String baseUrl}) = _Episodes;

  @GET('/shows/{id}/seasons/{season}/episodes/{episode}')
  Future<HttpResponse<dynamic>> getDetails(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET(
      '/shows/{id}/seasons/{season}/episodes/{episode}/translations/{language}')
  Future<HttpResponse<dynamic>> getTranslations(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Path('language') String language,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/episodes/{episode}/comments/{sort}')
  Future<HttpResponse<dynamic>> getComments(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Path('sort') ShowCommentsSortBy showCommentsSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/episodes/{episode}/lists/{type}/{sort}')
  Future<HttpResponse<dynamic>> getLists(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Path('type') MediaListTypes mediaListTypes,
    @Path('sort') MediaListSortBy mediaListSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/episodes/{episode}/people')
  Future<HttpResponse<dynamic>> getPeople(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/episodes/{episode}/ratings')
  Future<HttpResponse<dynamic>> getRatingDistribution(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/episodes/{episode}/stats')
  Future<HttpResponse<dynamic>> getStats(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/episodes/{episode}/watching')
  Future<HttpResponse<dynamic>> getUsersWatching(
    @Path('id') String showId,
    @Path('season') int seasonNumber,
    @Path('episode') int episodeNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
