import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'lists.g.dart';

@RestApi()
abstract class Lists {
  factory Lists(Dio dio, {String baseUrl}) = _Lists;

  @GET('/lists/trending')
  Future<HttpResponse<dynamic>> getTrending({
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/lists/popular')
  Future<HttpResponse<dynamic>> getPopular({
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/lists/{id}')
  Future<HttpResponse<dynamic>> getList(
    @Path('id') int listId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/lists/{id}/likes')
  Future<HttpResponse<dynamic>> getLikes(
    @Path('id') int listId, {
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/lists/{id}/items/{type}')
  Future<HttpResponse<dynamic>> getItems(
    @Path('id') int listId, {
    @Path('type') TraktMediaItemType traktMediaItemType,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
    @Header('X-Sort-By') ListSortBy listSortBy,
    @Header('X-Sort-How') ListSortHow listSortHow,
  });

  @GET('/lists/{id}/comments/{sort}')
  Future<HttpResponse<dynamic>> getComments(
    @Path('id') int listId, {
    @Path('sort') ListCommentsSortBy listCommentsSortBy,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
