import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'shows.g.dart';

@RestApi()
abstract class Shows {
  factory Shows(Dio dio, {String baseUrl}) = _Shows;

  @GET('/shows/trending')
  Future<HttpResponse<dynamic>> getTrending({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/popular')
  Future<HttpResponse<dynamic>> getPopular({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/recommended/{period}')
  Future<HttpResponse<dynamic>> getRecommended({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/played/{period}')
  Future<HttpResponse<dynamic>> getMostPlayed({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/watched/{period}')
  Future<HttpResponse<dynamic>> getMostWatched({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/collected/{period}')
  Future<HttpResponse<dynamic>> getMostCollected({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/anticipated')
  Future<HttpResponse<dynamic>> getAnticipated({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/updates/{start_date}')
  Future<HttpResponse<dynamic>> getUpdated({
    @Path('start_date') String startDate,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}')
  Future<HttpResponse<dynamic>> getDetails(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/aliases')
  Future<HttpResponse<dynamic>> getAliases(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/certifications')
  Future<HttpResponse<dynamic>> getCertifications(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/translations/{language}')
  Future<HttpResponse<dynamic>> getTranslations(
    @Path('id') String showId, {
    @Path('language') String language,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/comments/{sort}')
  Future<HttpResponse<dynamic>> getComments(
    @Path('id') String showId, {
    @Path('sort') ShowCommentsSortBy showCommentsSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/lists/{type}/{sort}')
  Future<HttpResponse<dynamic>> getLists(
    @Path('id') String showId, {
    @Path('type') MediaListTypes mediaListTypes,
    @Path('sort') MediaListSortBy mediaListSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/progress/collection')
  Future<HttpResponse<dynamic>> getCollectionProgress(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('hidden') bool includeHidden,
    @Query('specials') bool includeSpecials,
    @Query('count_specials') bool countSpecials,
    @Query('last_activity') ShowLastActivity showLastActivity,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/progress/watched')
  Future<HttpResponse<dynamic>> getWatchedProgress(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('hidden') bool includeHidden,
    @Query('specials') bool includeSpecials,
    @Query('count_specials') bool countSpecials,
    @Query('last_activity') ShowLastActivity showLastActivity,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/people')
  Future<HttpResponse<dynamic>> getPeople(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/ratings')
  Future<HttpResponse<dynamic>> getRatingDistribution(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/related')
  Future<HttpResponse<dynamic>> getRelated(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/stats')
  Future<HttpResponse<dynamic>> getStats(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/watching')
  Future<HttpResponse<dynamic>> getUsersWatching(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/next_episode')
  Future<HttpResponse<dynamic>> getNextEpisode(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/last_episode')
  Future<HttpResponse<dynamic>> getLastEpisode(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
