import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'users.g.dart';

@RestApi()
abstract class Users {
  factory Users(Dio dio, {String baseUrl}) = _Users;

  @GET('/users/settings')
  Future<HttpResponse<dynamic>> getSettings({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/requests/following')
  Future<HttpResponse<dynamic>> getPendingFollowingRequests({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/requests')
  Future<HttpResponse<dynamic>> getPendingFollowerRequests({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/requests/{id}')
  Future<HttpResponse<dynamic>> approveFollowerRequest(
    @Path('id') int requestId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @DELETE('/users/requests/{id}')
  Future<HttpResponse<dynamic>> denyFollowerRequest(
    @Path('id') int requestId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/hidden/{section}')
  Future<HttpResponse<dynamic>> getHiddenItems(
    @Path('section') UserSection userSection, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('type') TraktMediaItemType traktMediaItemType,
    @Query('client_id') String clientId,
    @Query('page') String page,
    @Query('limit') String limit,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/hidden/{section}')
  Future<HttpResponse<dynamic>> hideItemsInSection(
    @Path('section') UserSection userSection, {
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/hidden/{section}/remove')
  Future<HttpResponse<dynamic>> unhideItemsInSection({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/likes/{type}')
  Future<HttpResponse<dynamic>> getLiked({
    @Path('type') UserLikesType userLikesType,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('page') String page,
    @Query('limit') String limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}')
  Future<HttpResponse<dynamic>> getProfile(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/collection/{type}')
  Future<HttpResponse<dynamic>> getCollected(
    @Path('id') String userId, {
    @Path('type') AlternateMediaType alternateMediaType,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/comments/{comment_type}/{type}')
  Future<HttpResponse<dynamic>> getComments(
    @Path('id') String userId, {
    @Path('comment_type') CommentType commentType,
    @Path('type') AlternateMediaType alternateMediaType,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('include_replies') String includeReplies,
    @Query('client_id') String clientId,
    @Query('page') String page,
    @Query('limit') String limit,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/lists')
  Future<HttpResponse<dynamic>> getLists(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/{id}/lists')
  Future<HttpResponse<dynamic>> addList(
    @Path('id') String userId,
    @Body() TraktMediaItem traktMediaItem, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/{id}/lists/reorder')
  Future<HttpResponse<dynamic>> reorderLists(
    @Path('id') String userId,
    @Body() MediaItemReorderBody mediaItemReorderBody, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/lists/{list_id}')
  Future<HttpResponse<dynamic>> getList(
    @Path('id') String userId,
    @Path('list_id') String listId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @PUT('/users/{id}/lists/{list_id}')
  Future<HttpResponse<dynamic>> updateList(
    @Path('id') String userId,
    @Path('list_id') String listId,
    @Body() TraktMediaItem traktMediaItem, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @DELETE('/users/{id}/lists/{list_id}')
  Future<HttpResponse<dynamic>> deleteList(
    @Path('id') String userId,
    @Path('list_id') String listId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/lists/{list_id}/likes')
  Future<HttpResponse<dynamic>> getListLikes(
    @Path('id') String userId,
    @Path('list_id') String listId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') String page,
    @Query('limit') String limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/{id}/lists/{list_id}/like')
  Future<HttpResponse<dynamic>> likeList(
    @Path('id') String userId,
    @Path('list_id') String listId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @DELETE('/users/{id}/lists/{list_id}/like')
  Future<HttpResponse<dynamic>> unlikeList(
    @Path('id') String userId,
    @Path('list_id') String listId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/lists/{list_id}/items/{type}')
  Future<HttpResponse<dynamic>> getItems(
    @Path('id') String userId,
    @Path('list_id') String listId, {
    @Path('type') TraktMediaItemType traktMediaItemType,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Queries() Map<String, dynamic> additionalQueries,
    @Header('X-Sort-By') ListSortBy listSortBy,
    @Header('X-Sort-How') ListSortHow listSortHow,
  });

  @POST('/users/{id}/lists/{list_id}/items')
  Future<HttpResponse<dynamic>> addItemsToList(
    @Path('id') String userId,
    @Path('list_id') String listId,
    @Body() SynchCollectionBody synchCollectionBody, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/{id}/lists/{list_id}/items/remove')
  Future<HttpResponse<dynamic>> remoteItemsFromList(
    @Path('id') String userId,
    @Path('list_id') String listId,
    @Body() SynchCollectionBody synchCollectionBody, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/{id}/lists/{list_id}/items/reorder')
  Future<HttpResponse<dynamic>> reorderListItems(
    @Path('id') String userId,
    @Path('list_id') String listId,
    @Body() MediaItemReorderBody mediaItemReorderBody, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/lists/{list_id}/comments/{sort}')
  Future<HttpResponse<dynamic>> getListComments(
    @Path('id') String userId,
    @Path('list_id') String listId,
    @Path('sort') ListCommentsSortBy listCommentsSortBy, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('page') String page,
    @Query('limit') String limit,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/users/{id}/follow')
  Future<HttpResponse<dynamic>> followUser(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @DELETE('/users/{id}/follow')
  Future<HttpResponse<dynamic>> unfollowUser(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/followers')
  Future<HttpResponse<dynamic>> getAllFollowers(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/following')
  Future<HttpResponse<dynamic>> getAllFollowing(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/friends')
  Future<HttpResponse<dynamic>> getAllFriends(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/history/{type}/{item_id}')
  Future<HttpResponse<dynamic>> getHistory(
    @Path('id') String userId, {
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('item_id') String itemId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('start_at') String startAt,
    @Query('end_at') String endAt,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/ratings/{type}/{rating}')
  Future<HttpResponse<dynamic>> getRatings(
    @Path('id') String userId, {
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('rating') int rating,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/watchlist/{type}/{sort}')
  Future<HttpResponse<dynamic>> getWatchlist(
    @Path('id') String userId, {
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('sort') ListSortBy listSortBy,
    @Path('rating') int rating,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/recommendations/{type}/{sort}')
  Future<HttpResponse<dynamic>> getPersonalRecommendations(
    @Path('id') String userId, {
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('sort') ListSortBy listSortBy,
    @Path('rating') int rating,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/watching')
  Future<HttpResponse<dynamic>> getAllWatching(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/watched/{type}')
  Future<HttpResponse<dynamic>> getAllWatched(
    @Path('id') String userId,
    @Path('type') AlternateMediaType alternateMediaType, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/users/{id}/stats')
  Future<HttpResponse<dynamic>> getStats(
    @Path('id') String userId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
